import React, { Component } from 'react';
import { Field, reduxForm } from 'redux-form';
import PropTypes from 'prop-types';

class Form extends Component {
  static propTypes = {
    handleSubmit: PropTypes.func.isRequired,
    error: PropTypes.string
  };

  renderField = data => {
    data.input.className = 'form-control';

    const isInvalid = data.meta.touched && !!data.meta.error;
    if (isInvalid) {
      data.input.className += ' is-invalid';
      data.input['aria-invalid'] = true;
    }

    if (this.props.error && data.meta.touched && !data.meta.error) {
      data.input.className += ' is-valid';
    }

    return (
      <div className={`form-group`}>
        <label
          htmlFor={`transactionsentity_${data.input.name}`}
          className="form-control-label"
        >
          {data.input.name}
        </label>
        <input
          {...data.input}
          type={data.type}
          step={data.step}
          required={data.required}
          placeholder={data.placeholder}
          id={`transactionsentity_${data.input.name}`}
        />
        {isInvalid && <div className="invalid-feedback">{data.meta.error}</div>}
      </div>
    );
  };

  render() {
    return (
      <form onSubmit={this.props.handleSubmit}>
        <Field
          component={this.renderField}
          name="dateTransaction"
          type="dateTime"
          placeholder="Transaction date"
        />
        <Field
          component={this.renderField}
          name="price"
          type="number"
          step="0.1"
          placeholder="price of the transaction"
          normalize={v => parseFloat(v)}
        />
        <Field
          component={this.renderField}
          name="codeDepartment"
          type="text"
          placeholder="code of the department"
        />
        <Field
          component={this.renderField}
          name="region"
          type="text"
          placeholder="region of the transaction"
        />
        <Field
          component={this.renderField}
          name="squareMeters"
          type="number"
          placeholder="square meters of the home"
          normalize={v => parseFloat(v)}
        />

        <button type="submit" className="btn btn-success">
          Submit
        </button>
      </form>
    );
  }
}

export default reduxForm({
  form: 'transactionsentity',
  enableReinitialize: true,
  keepDirtyOnReinitialize: true
})(Form);
